@@ -8,7 +8,7 @@ our @ISA = qw(Exporter);
 our @EXPORT =
   qw(spp_repl match_text grammar_to_ast lint_grammar parse_text spp_to_spp);
 
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 use Spp::Builtin;
 use Spp::Tools;
 use Spp::Ast;
@@ -41,8 +41,7 @@ sub spp_repl {
 }
 
 sub match_text {
-  my ($ast, $text) = @_;
-  my $table  = ast_to_table($ast);
+  my ($table, $text) = @_;
   my $rule   = $table->{'door'};
   my $cursor = new_cursor($text, $table);
   my $match  = match_spp_rule($cursor, $rule);
@@ -57,7 +56,8 @@ sub grammar_to_ast {
   my $grammar  = shift;
   my $spp_ast  = get_spp_ast();
   my $estr_ast = to_ejson($spp_ast);
-  my ($match, $ok) = match_text($estr_ast, $grammar);
+  my $table    = ast_to_table($estr_ast);
+  my ($match, $ok) = match_text($table, $grammar);
   if ($ok) {
     my $ast = opt_spp_ast($match);
     lint_spp_ast($ast);
@@ -77,7 +77,8 @@ sub parse_text {
   my ($grammar, $text) = @_;
   my $ast = grammar_to_ast($grammar);
   lint_spp_ast($ast);
-  my ($match, $ok) = match_text($ast, $text);
+  my $table = ast_to_table($ast);
+  my ($match, $ok) = match_text($table, $text);
   if   ($ok) { return $match }
   else       { error($match) }
 }
@@ -85,7 +86,8 @@ sub parse_text {
 sub spp_to_spp {
   my $str     = shift;
   my $spp_ast = to_ejson(get_spp_ast());
-  my ($match, $ok) = match_text($spp_ast, $str);
+  my $table   = ast_to_table($spp_ast);
+  my ($match, $ok) = match_text($table, $str);
   if ($ok) {
     my $ast = opt_spp_ast($match);
     return ast_to_spp($ast);
