@@ -1,7 +1,7 @@
 package Spp::Grammar;
 
 use 5.012;
-no warnings "experimental";
+no warnings 'experimental';
 
 use Exporter;
 our @ISA    = qw(Exporter);
