@@ -166,12 +166,12 @@ sub match_spp_not {
 sub match_spp_till {
   my ($c, $rule) = @_;
   my $buf = [];
-  while ($c->{'off'} < $c->{'length'}) {
+  while ($c->{'off'} < $c->{'len'}) {
     my $char  = get_char($c);
     my $cache = cache($c);
     my $match = match_spp_rule($c, $rule);
     if (not(is_false($match))) {
-      my $gather_str = string($buf);
+      my $gather_str = join '', @{$buf};
       return gather_spp_match($gather_str, $match);
     }
     push @{$buf}, $char;
