@@ -1,12 +1,13 @@
 package Spp::ToSpp;
 
 use 5.012;
-no warnings "experimental";
+no warnings 'experimental';
 
 use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT =
   qw(ast_to_spp to_spp atoms_to_spp group_to_spp branch_to_spp rept_to_spp look_to_spp chclass_to_spp nclass_to_spp str_to_spp cclass_to_spp char_to_spp cchar_to_spp till_to_spp not_to_spp range_to_spp);
+
 use Spp::Builtin;
 use Spp::Tools;
 
@@ -18,7 +19,7 @@ sub ast_to_spp {
     my $rule_str = to_spp($rule);
     push @{$strs}, "$name = $rule_str";
   }
-  return join ';', @{ strings($strs) };
+  return join ';', @{$strs};
 }
 
 sub to_spp {
@@ -95,15 +96,12 @@ sub cclass_to_spp {
 sub char_to_spp {
   my $char = shift;
   given ($char) {
-    when (In)   { return '<' }
-    when (Out)  { return '>' }
-    when (Qstr) { return '#' }
-    when (Qint) { return '&' }
-    when ('"')  { return "\\\"" }
-    when ("\n") { return "\\n" }
-    when ("\r") { return "\\r" }
-    when ("\t") { return "\\t" }
-    when ("\\") { return "\\\\" }
+    when ("\n") { return '\n' }
+    when ("\r") { return '\r' }
+    when ("\t") { return '\t' }
+    when ("\\") { return '\\' }
+    when ('"')  { return '\"' }
+    when ("'")  { return '\'' }
     default     { return "'$char'" }
   }
 }
@@ -111,13 +109,13 @@ sub char_to_spp {
 sub cchar_to_spp {
   my $char = shift;
   given ($char) {
-    when ("\n") { return "\\n" }
-    when ("\r") { return "\\r" }
-    when ("\t") { return "\\t" }
-    when ("\\") { return "\\\\" }
-    when ('-')  { return "\\-" }
-    when (']')  { return "\\]" }
-    when ('^')  { return "\\^" }
+    when ("\n") { return '\n' }
+    when ("\r") { return '\r' }
+    when ("\t") { return '\t' }
+    when ("\\") { return '\\' }
+    when ('-')  { return '\-' }
+    when (']')  { return '\]' }
+    when ('^')  { return '\^' }
     default     { return $char }
   }
 }
