@@ -6,31 +6,20 @@ no warnings 'experimental';
 use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT =
-  qw(is_type is_atom is_atoms to_ejson from_ejson char_to_ejson atoms flat match name value offline elen epush eappend eunshift ejoin is_atom_name is_sym is_rept is_look is_tillnot is_atom_str is_sub is_return ast_to_table get_rept_time clean_ast clean_atom see_ast is_exported);
+  qw(is_type is_atoms to_ejson from_ejson char_to_ejson atoms flat match name value offline elen epush eappend eunshift ejoin is_atom_name is_sym is_rept is_look is_tillnot is_atom_str is_sub is_return ast_to_table get_rept_time clean_ast clean_atom see_ast is_exported);
 
 use Spp::Builtin;
 
 sub is_type {
   my $str = shift;
   return $str ~~ [
-    'Str',  'Int',   'Bool', 'Cursor',
-    'Lint', 'Array', 'Stack'
+    'Str',  'Int',   'Bool',       'Cursor',
+    'Lint', 'Array', 'Ints',       'Hash',
+    'Str+', 'Int+',  'StrOrArray', 'Str?',
+    'Int?', 'Fn',    'Table',      'Map'
   ];
 }
 
-sub is_atom {
-  my $atom = shift;
-  if (is_estr($atom)) {
-    if (len($atom) < 4) { return 0 }
-    my $atoms = atoms($atom);
-    if (len($atoms) > 0) {
-      my $name = $atoms->[0];
-      return is_str($name);
-    }
-  }
-  return 0;
-}
-
 sub is_atoms {
   my $atoms = shift;
   if (is_estr($atoms)) {
@@ -84,7 +73,7 @@ sub to_ejson {
       }
     }
   }
-  return string($chars);
+  return join '', @{$chars};
 }
 
 sub from_ejson {
@@ -128,7 +117,7 @@ sub from_ejson {
       }
     }
   }
-  return string($chars);
+  return join '', @{$chars};
 }
 
 sub char_to_ejson {
@@ -158,28 +147,28 @@ sub atoms {
         when (In) {
           $depth++;
           if ($mode) {
-            push @{$estrs}, string($chars);
-            clean($chars);
+            push @{$estrs}, join '', @{$chars};
+            $chars = [];
           }
           $mode = 1;
           push @{$chars}, $ch;
         }
         when (Qstr) {
           if ($mode) {
-            push @{$estrs}, string($chars);
-            clean($chars);
+            push @{$estrs}, join '', @{$chars};
+            $chars = [];
           }
           $mode = 1
         }
         when (Qint) {
           if ($mode) {
-            push @{$estrs}, string($chars);
-            clean($chars);
+            push @{$estrs}, join '', @{$chars};
+            $chars = [];
           }
           $mode = 1
         }
         when (Out) {
-          if ($mode) { push @{$estrs}, string($chars); }
+          if ($mode) { push @{$estrs}, join '', @{$chars}; }
         }
         default {
           if ($mode) { push @{$chars}, $ch; }
